@@ -495,12 +495,12 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "VET",
             };
         final String[] JRE_Europe_Istanbul = new String[] {
-               "Eastern European Time",
-               "EET",
-               "Eastern European Summer Time",
-               "EEST",
-               "Eastern European Time",
-               "EET",
+               "Turkey Time",
+               "TRT",
+               "Turkey Summer Time",
+               "TRST",
+               "Turkey Time",
+               "TRT",
             };
         final String[] Phoenix_Islands = new String[] {
                "Phoenix Islands Time",
@@ -807,12 +807,12 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "AMT",
             };
         final String[] JRE_Turkey = new String[] {
-               "Eastern European Time",
-               "EET",
-               "Eastern European Summer Time",
-               "EEST",
-               "Eastern European Time",
-               "EET",
+               "Turkey Time",
+               "TRT",
+               "Turkey Summer Time",
+               "TRST",
+               "Turkey Time",
+               "TRT",
             };
         final String[] Africa_Central = new String[] {
                "Central Africa Time",
@@ -1335,12 +1335,12 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "GT",
             };
         final String[] JRE_Asia_Istanbul = new String[] {
-               "Eastern European Time",
-               "EET",
-               "Eastern European Summer Time",
-               "EEST",
-               "Eastern European Time",
-               "EET",
+               "Turkey Time",
+               "TRT",
+               "Turkey Summer Time",
+               "TRST",
+               "Turkey Time",
+               "TRT",
             };
         final String[] Easter = new String[] {
                "Easter Island Standard Time",
